# This file is part of Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

try:
    from trytond.modules.account_be.tests.test_account_be import suite
except ImportError:
    from .test_account_be import suite

__all__ = ['suite']
